@@ -13,10 +13,10 @@
 
    Copyright 2022, HSPyLib team
 """
+from datasource.db_configuration import DBConfiguration
 
 
-
-class VaultConfig(SQLiteConfiguration):
+class VaultConfig(DBConfiguration):
     """Holds the vault configurations"""
 
     INSTANCE = None
